Bundle loading utilities.
The BundleLoader provides functionality to load and extract plugin bundles.
Structs
- Bundle
Loader - Loader for plugin bundles.
Bundle loading utilities.
The BundleLoader provides functionality to load and extract plugin bundles.